@@ -57,7 +57,7 @@ class NaPoleonDropboxConnector(object):
 
     def local_features_npy_ovverwrite_and_load_array(self, starting_date = None, ending_date = None, feature_type=None,
                                            n_past_features=None, local_root_directory='', user='',
-                                           features_saving_suffix='', features_names_saving_suffix='',shortcut_features_saving_suffix = ''):
+                                           features_saving_suffix='', features_names_saving_suffix='',shortcut_features_saving_suffix = '',shortcut_features_names_saving_suffix=''):
         features_file_name = starting_date.strftime('%d_%b_%Y')+'_'+ending_date.strftime('%d_%b_%Y') +'_'+user + '_' + feature_type.name + '_' + str(n_past_features) + features_saving_suffix
         local_root_directory = Path(local_root_directory)
         features_full_path = local_root_directory/features_file_name
@@ -89,9 +89,19 @@ class NaPoleonDropboxConnector(object):
             f.write(res_feat)
             f.close()
 
-        shortcut_features = pd.read_pickle(shortcut_features_file_full_path)
+        shortcut_features = np.load(shortcut_features_file_full_path)
 
-        return features, features_names, shortcut_features
+
+        shortcut_features_names_file_names = user+shortcut_features_names_saving_suffix
+        shortcut_features_names_full_path = local_root_directory/shortcut_features_names_file_names
+        if self.dropbox_backup:
+            res_feat_names = self.download(folder='', subfolder='', name=shortcut_features_names_file_names)
+            f = open(features_names_full_path, 'wb')
+            f.write(res_feat_names)
+            f.close()
+        shortcut_features_names = np.load(shortcut_features_names_full_path)
+
+        return features, features_names, shortcut_features, shortcut_features_names
 
     def local_supervision_npy_overwrite_and_load_array(self, starting_date = None, ending_date = None,  rebal=None,  lower_bound=0.02, upper_bound=0.4, local_root_directory='', user='',supervision_npy_file_suffix=''):
         supervision_file_name = starting_date.strftime('%d_%b_%Y')+'_'+ending_date.strftime('%d_%b_%Y')+'_'+user + '_' + str(rebal)  + '_' + str(lower_bound)+ '_' + str(upper_bound) +  supervision_npy_file_suffix
