@@ -734,40 +734,21 @@ def rolling_allocation(f, X, n=252, s=63, ret=True, drift=True, filtering_thresh
     return portfolio, w_mat
 
 
-def rolling_ensembling(X, w_mat_predictors_list, w_mat_target, n=252, s=63,ret=True, ensembling_model = 'mean', period = 252, **kwargs):
+def rolling_ensembling(X, w_mat_predictors_list, w_mat_target, n=252, s=63,ret=True, ensembling_model = 'other', period = 252, **kwargs):
     assert len(w_mat_predictors_list) > 1
     X = pd.DataFrame(X).fillna(method='ffill')
     if ret:
         X_ = X.pct_change()
     else:
         X_ = X
-
-    if ensembling_model == 'mean':
-        index_tmp = w_mat_predictors_list[0].index
-        columns_tmp = w_mat_predictors_list[0].columns
-        to_np = lambda my_df : my_df.values
-        w_mat_predictors_list = list(map(to_np, w_mat_predictors_list))
-        np_mean_weights = None
-        for np_weights in w_mat_predictors_list:
-            if np_mean_weights is None :
-                np_mean_weights = np_weights
-            else :
-                np_mean_weights = np_mean_weights + np_weights
-        np_mean_weights = np_mean_weights/len(w_mat_predictors_list)
-        w_mat = pd.DataFrame(data = np_mean_weights,index=index_tmp, columns=columns_tmp)
-        portfolio = np.cumprod(np.prod(X_ * w_mat.values + 1, axis=1))
-        return portfolio, w_mat
-    else:
+    if ensembling_model == 'min_sharpe':
         to_apply = lambda my_df : pd.DataFrame(my_df).fillna(0)
         w_mat_predictors_list = list(map(to_apply, w_mat_predictors_list))
-
         idx = w_mat_predictors_list[0].index
         w_mat = pd.DataFrame(index=idx, columns=w_mat_target.columns)
         portfolio = pd.Series(100., index=idx, name='portfolio')
         roll = rolling._EnsemblingRollingMechanism(idx, n=n, s=s)
-
         for slice_n, slice_s in roll():
-
             train_ret = X_.loc[slice_n].copy()
             train_forward_looking = w_mat_target.loc[slice_n].copy()
             test_forward_looking = w_mat_target.loc[slice_s].copy()
@@ -793,6 +774,23 @@ def rolling_ensembling(X, w_mat_predictors_list, w_mat_target, n=252, s=63,ret=T
             portfolio.loc[slice_s] = portfolio.loc[roll.d] * perf.flatten()
         w_mat = w_mat.fillna(method='ffill').fillna(0.)
         return portfolio, w_mat
+    else :
+        print('defaulting to simple average')
+        index_tmp = w_mat_predictors_list[0].index
+        columns_tmp = w_mat_predictors_list[0].columns
+        to_np = lambda my_df : my_df.values
+        w_mat_predictors_list = list(map(to_np, w_mat_predictors_list))
+        np_mean_weights = None
+        for np_weights in w_mat_predictors_list:
+            if np_mean_weights is None :
+                np_mean_weights = np_weights
+            else :
+                np_mean_weights = np_mean_weights + np_weights
+        np_mean_weights = np_mean_weights/len(w_mat_predictors_list)
+        w_mat = pd.DataFrame(data = np_mean_weights,index=index_tmp, columns=columns_tmp)
+        portfolio = np.cumprod(np.prod(X_ * w_mat.values + 1, axis=1))
+        return portfolio, w_mat
+
 
 
 # =========================================================================== #
