@@ -15,16 +15,18 @@ def generate_lead_lag(lookback_windows, contravariants, ranging_stride, starting
                 })
     return parameters
 
-def generate_dd_threshold(lookback_windows, thresholds, contravariants):
+def generate_dd_threshold(lookback_windows, thresholds, lags, contravariants):
     parameters = []
     for lookback_window in lookback_windows:
         for contravariant in contravariants:
             for threshold in thresholds:
-                parameters.append({
-                    'lookback_window':lookback_window,
-                    'contravariant':contravariant,
-                    'threshold':threshold
-                })
+                for lag in lags:
+                    parameters.append({
+                        'lookback_window':lookback_window,
+                        'contravariant':contravariant,
+                        'threshold':threshold,
+                        'lag':lag
+                    })
     return parameters
 
 def generate_lookback_only(lookback_windows):
