@@ -251,12 +251,17 @@ def slope_induced(data = None, contravariant = -1., up_trend_threshold=0.8, low_
     data['volu_hi_low'] = data['aggregated_volume']*data['hl']
 
     data['close_ret']=data['close'].pct_change()
+    data['high_ret']=data['aggregated_high'].pct_change()
 
     data['volu_hi_low_pct_rank'] = data['volu_hi_low'].rank(pct=True)
     data['close_ret_pct_rank'] = data['close_ret'].rank(pct=True)
+    data['high_ret_pct_rank'] = data['high_ret'].rank(pct=True)
 
-    trend_rank = data['close_ret_pct_rank'].iloc[-1]
-    #vol_rank = data['volu_hi_low_pct_rank'].iloc[-1]
+    trend_rank = np.nan
+    if slope_column == 'close':
+        trend_rank = data['close_ret_pct_rank'].iloc[-1]
+    elif slope_column == 'high':
+        trend_rank = data['high_ret_pct_rank'].iloc[-1]
 
     if trend_rank > up_trend_threshold:
         return contravariant
@@ -305,7 +310,25 @@ def slope_induced_cont(data = None, contravariant = -1., lag = 2, slope_column =
 
     return contravariant*signal
 
-def counting_candles(data= None, threshold = 1., contravariant = -1, **kwargs):
+def counting_candles(data= None, threshold = 1., contravariant = -1., lag = 2, **kwargs):
+    ## aggregating the volumes by lag
+    data.index = range(0,len(data))
+    all_indices = list(reversed(range(len(data) - 1, 0, -lag)))
+    data['aggregated_indice'] = np.nan
+    data['aggregated_indice'].loc[all_indices] = all_indices
+    data['aggregated_indice']= data['aggregated_indice'].fillna(method='bfill')
+    data['aggregated_indice'] = data['aggregated_indice'].astype(int)
+    volumefrom = data.groupby(['aggregated_indice'])['volumefrom'].agg('sum')
+    high = data.groupby(['aggregated_indice'])['high'].agg('max')
+    low = data.groupby(['aggregated_indice'])['low'].agg('min')
+
+    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom)
+    data['aggregated_high'] =  data['aggregated_indice'].map(high)
+    data['aggregated_low'] =  data['aggregated_indice'].map(low)
+
+    data = data[::-lag]
+    data = data.iloc[::-1]
+
     me_values = (data.close.diff() >= 0.).astype(float).value_counts()
     try:
         one_count = me_values[1.]
